@@ -20,7 +20,7 @@ def get_or_none(list_, idx):
     return list_[idx] if idx < len(list_) else None
 
 
-def open_file(*args, **kwargs):
+def open_file(*args, **kwargs):  # for easier mocked unit_tests
     return open(*args, **kwargs)
 
 
@@ -63,6 +63,8 @@ class Dataset(object):
 
     INPUT_TYPES = [INPUT_TYPE_FILE, INPUT_TYPE_URL, INPUT_TYPE_DATA]
 
+    client = Client()
+
     def __init__(self, items, ids=None, custom_ids=None, labels=None, **kwargs):
 
         self.items = self.prepare_items(items, **kwargs)
@@ -76,8 +78,6 @@ class Dataset(object):
         self.labels = labels or []
         self.ids = ids or []
 
-        self.client = Client()
-
     def __len__(self):
         return len(self.items)
 
@@ -279,7 +279,7 @@ class FileDataset(Dataset):
         if custom_id:
             data["custom_id"] = (None, custom_id)
         if label:
-            data["initial_label"] = (None, label)
+            data["initial_label"] = (None, json.dumps(label))
 
         return data
 
@@ -367,9 +367,6 @@ class TrainingsetMixin(object):
             resp["is_training"] = (None, True)
         else:
             resp["is_training"] = True
-
-        resp["label"] = resp["initial_label"]
-        resp.pop("initial_label")
         return resp
 
 
@@ -398,25 +395,25 @@ class Trainingset(Dataset):
         return class_map[input_type]
 
     @classmethod
-    def from_list(cls, *args, required_score=0.9, **kwargs):
+    def from_list(cls, *args, required_score=None, **kwargs):
         instance = super().from_list(*args, **kwargs)
         instance.required_score = required_score
         return instance
 
     @classmethod
-    def from_folder(cls, *args, required_score=0.9, **kwargs):
+    def from_folder(cls, *args, required_score=None, **kwargs):
         instance = super().from_folder(*args, **kwargs)
         instance.required_score = required_score
         return instance
 
     @classmethod
-    def from_csv(cls, *args, required_score=0.9, **kwargs):
+    def from_csv(cls, *args, required_score=None, **kwargs):
         instance = super().from_csv(*args, **kwargs)
         instance.required_score = required_score
         return instance
 
     @classmethod
-    def from_dataframe(cls, *args, required_score=0.9, **kwargs):
+    def from_dataframe(cls, *args, required_score=None, **kwargs):
         instance = super().from_dataframe(*args, **kwargs)
         instance.required_score = required_score
         return instance
