@@ -26,6 +26,13 @@ class InvalidParameter(Exception):
         super().__init__(message)
 
 
+class MissingId(Exception):
+    def __init__(
+        self, message="Missing taskframe id. You probably need to call submit() first."
+    ):
+        super().__init__(message)
+
+
 class Taskframe(object):
 
     client = Client()
@@ -68,6 +75,7 @@ class Taskframe(object):
         self.id = id
         self.dataset = None
         self.trainingset = None
+        self.team = None
         self.review = review
         self.redundancy = redundancy
         self.callback_url = callback_url
@@ -177,6 +185,8 @@ class Taskframe(object):
             self.submit_training_requirement(
                 required_score=self.trainingset.required_score
             )
+        if self.team:
+            self.submit_team()
 
     @classmethod
     def _create_from_dict(cls, data):
@@ -216,6 +226,14 @@ class Taskframe(object):
             """
         return display(HTML(html))
 
+    def get_url(self):
+        if not self.id:
+            raise MissingId()
+        return f"{APP_ENDPOINT}/taskframes/{self.id}"
+
+    def open(self):
+        display(Javascript(f'window.open("{self.get_url()}", "_blank");'))
+
     def progress(self):
         """Returns a dict of metrics related to the progress of the taskframe"""
         api_data = self.retrieve_data(self.id)
@@ -299,11 +317,13 @@ class Taskframe(object):
 
         return pandas.DataFrame(tasks)
 
-    def merge_to_dataframe(self, dataframe, custom_id_column):
-        answer_dataframe = self.to_dataframe()
-        output_columns = list(dataframe.columns) + ["label"]
-        return dataframe.merge(
-            answer_dataframe, left_on=custom_id_column, right_on="custom_id"
+    def merge_to_dataframe(self, initial_dataframe, custom_id_column):
+        exported_dataframe = self.to_dataframe()
+        if "label" in initial_dataframe.columns:
+            initial_dataframe = initial_dataframe.drop("label", axis=1)
+        output_columns = list(initial_dataframe.columns) + ["label"]
+        return initial_dataframe.merge(
+            exported_dataframe, left_on=custom_id_column, right_on="custom_id"
         )[output_columns]
 
     def to_csv(self, path):
